#[repr(u8)]pub enum Sstart {
VALUE00 = 0,
VALUE01 = 1,
VALUE10 = 2,
VALUE11 = 3,
}Variants
VALUE00 = 0
Start bit disabled for Transmitter, Receiver, and Match Store modes; Transmitter mode loads data on enable
VALUE01 = 1
Start bit disabled for Transmitter, Receiver, and Match Store modes; Transmitter mode loads data on first shift
VALUE10 = 2
Transmitter mode outputs start bit value 0 before loading data on first shift; if start bit is not 0, Receiver and Match Store modes set error flag
VALUE11 = 3
Transmitter mode outputs start bit value 1 before loading data on first shift; if start bit is not 1, Receiver and Match Store modes set error flag
Implementations